| jd3_utilities | R Documentation |
These functions are used in all JDemetra+ 3.0 packages to easily interact between R and Java objects.
.x13_rslts(jrslts)
.jd2r_spec_x11(jspec)
.r2jd_spec_x11(spec)
.r2jd_spec_regarima(spec)
.jd2r_spec_regarima(jspec)
.r2jd_spec_x13(spec)
.jd2r_spec_x13(jspec)
spec, jspec, jrslts |
parameters. |
These functions return specification in Java, proto or R.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.