| set_x11 | R Documentation |
Set X-11 Specification
set_x11(
x,
mode = c(NA, "Undefined", "Additive", "Multiplicative", "LogAdditive",
"PseudoAdditive"),
seasonal.comp = NA,
seasonal.filter = NA,
henderson.filter = NA,
lsigma = NA,
usigma = NA,
fcasts = NA,
bcasts = NA,
calendar.sigma = c(NA, "None", "Signif", "All", "Select"),
sigma.vector = NA,
exclude.forecast = NA,
bias = c(NA, "LEGACY")
)
x |
the specification to be modified, object of class "JD3_X11_SPEC", default X11 spec can be obtained as 'x=x11_spec()' |
mode |
character: the decomposition mode. Determines the mode of the
seasonal adjustment decomposition to be performed:
|
seasonal.comp |
logical: if |
seasonal.filter |
a vector of character(s) specifying which seasonal
moving average (i.e. seasonal filter) will be used to estimate the seasonal
factors for the entire series. The vector can be of length: 1 - the same
seasonal filter is used for all periods (e.g.: |
henderson.filter |
numeric: the length of the Henderson filter (odd
number between 3 and 101). If |
lsigma |
numeric: the lower sigma boundary for the detection of extreme values, > 0.5, default=1.5. |
usigma |
numeric: the upper sigma boundary for the detection of extreme values, > lsigma, default=2.5. |
bcasts, fcasts |
numeric: the number of backcasts ( |
calendar.sigma |
character to specify if the standard errors used for
extreme values detection and adjustment are computed: from 5 year spans of
irregulars ( |
sigma.vector |
a vector to specify one of the two groups of periods for
which standard errors used for extreme values detection and adjustment will
be computed separately. Possible values are: |
exclude.forecast |
Boolean to exclude forecasts and backcasts. If
|
bias |
TODO. |
a "JD3_X11_SPEC" object, containing all the parameters.
x13_spec() and x11_spec().
init_spec <- x11_spec()
new_spec <- set_x11(init_spec,
mode = "LogAdditive",
seasonal.comp = 1,
seasonal.filter = "S3X9",
henderson.filter = 7,
lsigma = 1.7,
usigma = 2.7,
fcasts = -1,
bcasts = -1,
calendar.sigma = "All",
sigma.vector = NA,
exclude.forecast = FALSE,
bias = "LEGACY"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.