| x13_dictionary | R Documentation |
Functions to provide information for all output objects (series, diagnostics,
parameters) available with x13() function.
x13_dictionary()
x13_full_dictionary()
These functions provide lists of output names (series, diagnostics,
parameters) available with the x13() function. These names can be
used to generate customized outputs with the userdefined option of the
x13() function (see examples).
The x13_full_dictionary function provides additional information on
object format and description.
x13_dictionary() returns a character vector containing the
names of all output objects (series, diagnostics, parameters) available with
the x13() function, whereas x13_full_dictionary() returns a
data.frame with format and description, for all the output objects.
library("rjd3toolkit")
# Visualize the dictionary
print(x13_dictionary())
summary(x13_dictionary())
# first 10 lines
head(x13_full_dictionary(), n = 10)
# For more structured information call `View(x13_full_dictionary())`
# Extract names of output of interest
user_defined_output <- x13_dictionary()[c(65, 95, 135)]
user_defined_output
# Generate the corresponding output in an estimation
y <- ABS$X0.2.09.10.M
m <- x13(y,"rsa3", userdefined=user_defined_output)
# Retrieve user defined output
tail(m$user_defined$ylin)
m$user_defined$residuals.kurtosis
m$user_defined$sa_f
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.